//
//  RootViewController.m
//  TestTwitterClient
//
//  Created by Akabeko on 11/09/24.
//  Copyright 2011, Akabeko. All rights reserved.
//

#import "TimelineViewController.h"
#import "TweetCellController.h"
#import "TweetTimeline.h"
#import "Tweet.h"

@interface TimelineViewController()
- (IBAction)refresh:(id)sender;
@end

@implementation TimelineViewController

/**
 * View が読み込まれる時に発生します。
 */
- (void)viewDidLoad
{
    [super viewDidLoad];

    NSString* userId = @"akabekobeko";
    
    self.title = userId;
    _timeline = [[TweetTimeline alloc] initWithUser:userId];

    self.navigationController.navigationBar.barStyle = UIBarStyleBlack;
    
    // 再読み込みボタン
    UIBarButtonItem* button = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemRefresh target:self action:@selector(refresh:)];
    self.navigationItem.rightBarButtonItem = button;
    [button release];
}

/**
 * View が破棄される時に発生します。
 */
- (void)viewDidUnload
{
    [_timeline release];
    _timeline = nil;
    
    [super viewDidUnload];
}

/**
 * メモリを解放します。
 */
- (void)dealloc
{
    [_timeline release];
    
    [super dealloc];
}

/**
 * セクション数を取得します。
 *
 * @param tableView テーブル。
 *
 * @return セクション数。
 */
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

/**
 * セクション内の行数を取得します。
 *
 * @param tableView テーブル。
 * @param section   セクション。
 *
 * @return 行数。
 */
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return _timeline.count;
}

/**
 * セルを取得します。
 *
 * @param tableView テーブル。
 * @param indexPath インデックス。
 *
 * @return セル。
 */
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString* CellIdentifier = @"TweetCell";

    TweetCell* cell = ( TweetCell* )[tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if( cell == nil )
    {
        TweetCellController* controller = [[TweetCellController alloc] initWithNibName:@"TweetCellController" bundle:nil];
        cell = ( TweetCell* )controller.view;
        [controller release];
    }
  
    Tweet* tweet = [_timeline tweetAtIndex:indexPath.row];
    
    cell.icon           = tweet.icon;
    cell.name           = tweet.name;
    cell.tweet          = tweet.text;
    cell.date           = tweet.created;
    cell.selectionStyle = UITableViewCellSelectionStyleNone;

    return cell;
}

/**
 * 行の高さを算出します。
 *
 * @param tableView テーブル。
 * @param indexPath インデックス。
 *
 * @return 高さ。
 */
- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    Tweet* tweet = [_timeline tweetAtIndex:indexPath.row];
    return [TweetCell calcHeight:tweet.text];
}

#pragma mark Private methods

/**
 * 再読み込みを実行します。
 */
- (IBAction)refresh:(id)sender
{
    [_timeline reload];
    [self.tableView reloadData];
}

@end
